#ifndef _BLINKMSG_H
#define _BLINKMSG_H

#include "Location.h"
#include "Frame.h"

/*
CLASS
   BlinkingMessage

   A BlinkingMessage encapsulates the state and functionality to support a
   "blinking" text string. The state of a BlinkingMessage object records
   whether the text string is currently visible and, when asked to "blink"
   either draws itself (if it is currently not visible) or erases itself
   (if it is currently visible).
*/

class BlinkingMessage {
 private:
   char     *text;               // text being displayed
   Location  location;           // at this location
   Frame    *frame;              // in this window
   int       visible;

   void Clear();
   void Draw();

 public:

   //////////
   // Construct a BlinkingMessage with the given text string and 
   // a given location. 
   //<UL>
   //<LI><B>textString</B>: the text string that will be drawn and
   // erased</LI>
   //<LI><B>whereat</B>: the Location in a Frame where the BlinkingMessage's
   // text string will appear when it is visible.</LI>
   //</UL>
   BlinkingMessage(char *textString, Location whereAt);

   //////////
   // Construct a BlinkingMessage with a default text string at
   // a given location. 
   //<UL>
   //<LI><B>whereAt</B>: the Location in a Frame where the BlinkingMessage's
   // text string will appear when it is visible.</LI>
   //</UL>
   BlinkingMessage(Location whereAt);


   //////////
   // Indicate in which Frame the BlinkingMessage will appear.
   //<UL>
   //<LI><B>whichFrame</B>: the identity (by reference) of the Frame
   // in which the BlinkingMessage's text string will be displayed when
   // the text string is visible.</LI>
   //</UL>
   void DisplayIn(Frame& whichFrame);

   //////////
   // Change the Location at which the text string appears.
   //<UL>
   //<LI><B>newLocation</B>: the new Location at which the text string
   // will appear when the BlinkingMessage is visible.</LI>
   //</UL>
   void MoveTo(Location newLocation);

   //////////
   // Change or set the text string of the BlinkingMessage. If the
   // current BlinkingMessage is visible, the current text string is
   // erased and the current text string is drawn. If the BlinkingMessage
   // is not currently visible, then the new text string will appear the
   // next time the BlinkingMessage's text becomes visible.
   //<UL>
   //<LI><B>newText</B>: the text string which should now blink. 
   //</LI>
   //</UL>
   void SetText(char *newText);

   //////////
   // Return the current text string.
   char *GetText();

   //////////
   // This is the principle method of the BlinkingMessage class. This
   // method causes the text to be erased (if the text string is currently 
   // visible) or drawn (if the text string is currently not visible).
   void Blink();

   //////////
   // This method repaints the text string without changing the state
   // (the visibility) of the text. This method is used in repainting
   // a Frame that contains a BlinkingMessage text string. 
   void Redraw();


   //////////
   // Reclaim all resources associated with the BlinkingMessage object.
   ~BlinkingMessage();
};

#endif



