#ifndef _FRAME_H
#define _FRAME_H

#include "wx.h"
#include "BscFrame.h"
#include "Location.h"
#include "Shape.h"


class Message;
class BlinkingMessage;

/* 
CLASS
   Frame

 This class represents the abstraction of a graphical user interface
 window. The methods of this class allow for simple text and graphics
 to be displayed in the window. Under program control, the window
 may be moved on the user's display and its shape may be changed.
 Each Frame is given a name that is appears on the title bar of the
 visible window and is used to identify the Frame when mouse events
 occur in that window.
 The location of a Frame on the user's display is measured in a
  coordinate system where the upper left-hand corner of the display is
  the coordinates (0,0), the x-axis is the top of the display with higher
  x values to the right, and the y-axis is the left edge of the display
  with higher values nearer the bottom of the display.
  The shape of a Frame is given by it width and height, both measures
  in pixels. 

*/



class Frame {
private:

   char       *name;
   BasicFrame *frame;
   Location    location;
   Shape       shape;

   void CreateIfNeeded();
   friend  Message;
   friend  BlinkingMessage;

public:

   //////////
  //
  //Construct a Frame object specifying the Frame's name, its location -
  //the x and y coordinates, and its shape - its width and height.
  //<UL>
  //<LI><B>name</B> this string defines the name of the Frame. This string 
  //           will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //<LI><B>location</B> the coordinates of where the Frame's upper left-hand
  //           corner is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //<LI><B>shape</B> the height and width of the Frame, measured in pixels.
  //</UL>
   Frame(char *name, Location location, Shape shape);


   //////////
  //
  //Construct a Frame object specifying the Frame's name, and its Location.
  //The Frame is constructed with a default Shape.
  //<UL>
  //<LI><B>name</B> this string defines the name of the Frame. This string 
  //           will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //<LI><B>location</B> the coordinates of where the Frame's upper left-hand
  //           corner is located on the user's
  //           display relative to the upper left-hand corner of the display.
  //</UL>
   Frame(char* name, Location loc);


   //////////
  //
  //Construct a Frame object specifying the Frame's name, and its Shape.
  //The Frame is constructed at a default Location.
  //<UL>
  //<LI><B>name</B> this string defines the name of the Frame. This string 
  //           will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //<LI><B>shape</B> the height and width of the Frame, measured in pixels.
  //</UL>
   Frame(char* name, Shape sh);

   //////////
  //
  //Construct a Frame object specifying the Frame's name. Both the Location
  //and the Shape of the Frame are determined by defaults.
  //<UL>
  //<LI><B>name</B> this string defines the name of the Frame. This string 
  //           will
  //            appear on the top border of the window on the user's
  //            display and, when a mouse event occurs in a window, this
  //            name will be passed to the OnMouseEvent method so that the
  //            program will know in which Frame the event occured.</LI>
  //</UL>
   Frame(char* name);


   //////////
  //
  //Construct a Frame object specifying. The Frame's name, its Location, and
  //its Shape are given default values.
   Frame();

  //////////
  // Destructor: frees resources when Frame object is deleted
  ~Frame();
            
   //////////
   // Move the Frame's visible window to a specified Location.
   //<UL>
   //<LI><B>location</B>: the new position of the upper left-hand
   //corner of the Frame's visible window.
   //</UL>
   void     MoveTo(Location location);          

   //////////
   // Change the dimensions of the Frame's visible window to a 
   // specified Shape.
   //<UL>
   // <LI><B>shape</B>: the new dimensons for the window.
   //</UL>
   void     Resize(Shape shape);                   

   //////////
   // Change the dimensions of the Frame's visible window by multiplying
   // each dimension by a given amount.
   //<UL>
   // <LI><B>factor</B>: the amount by which the window's height and
   //width are multiplied. If factor &gt; 1, the window will increase in
   //size. If factor &lt; 1, the window will decrease in size.
   //</UL>
   void     Resize( float factor);              
  
   //////////
   // Draw a text string in the Frames' visible window starting at the
   // specified location.
   //<UL>
   // <LI><B>msg</B>: the text string to be drawn. </LI>
   // <LI><B>location</B>: the upper left-hand corner of where within
   //the window the first character of the string will be drawn. The
   //coordinates of the Location are interpreted with respect to the
   // upper left-hand corner of the window.</LI>
   //</UL>
   void     DrawText(char* msg, Location location);  

   //////////
   // Return the Shape of the rectangular area occupied in the window
   // by the given text string. This method is useful in erasing a
   // given text string (see the Clear method)
   //<UL>
   // <LI><B>msg</B>: the text string whose shape is determined. </LI>
   //</UL>
   Shape    TextSize (char* msg);               

   //////////
   // Draw a line segment between two points whose Locations are specified.
   //<UL>
   // <LI><B>p1</B>: one end of the line segment. </LI>
   // <LI><B>p2</B>: the other end of the line segment.</LI>
   //</UL>
   void     DrawLine(Location p1,               // draw line from point p1
                     Location p2);              //           to   point p2

   //////////
   // Draw a circle of the specified radius about a specified centerpoint.
   //<UL>
   // <LI><B>center</B>: the center point of the circle. </LI>
   // <LI><B>radius</B>: the radius of the circle.</LI>
   //</UL>
   void     DrawCircle(Location center, int radius);

   //////////
   // Erase the contents of the Frame's visible window.
   void     Clear();                            

   //////////
   // Erase a specified rectangular region of the Frame's visible window.
   //Only the specified rectangular region is affected.
   //<UL>
   // <LI><B>location</B>: the coordinates of the upper left-hand
   // corner of the rectangular area to be erased.</LI>
   // <LI><B>shape</B>: the height and width of the rectangular
   // area to be erased.</LI>
   //</UL>
   void     Clear(Location location, Shape shape);      

   //////////
   // Reply if the given string is equal to the name of the Frame.
   //<UL>
   // <LI><B>name</B>: Return 1 if this string matches the name given
   // to the Frame when the Frame was constructed. Return 0 otherwise.</LI>
   //</UL>
   int      IsNamed(char* name);                   
};


#endif







