#ifndef _MESSAGE_H
#define _MESSAGE_H

#include "Location.h"
#include "Frame.h"

/*
CLASS
  Message

  This class captures the abstraction of a text string that can be
  drawn and erased from a given Location in a Frame with which the
  Message is associated.

*/

class Message {
 private:
   char     *text;               // text being displayed
   Location  location;           // at this location
   Frame    *frame;              // in this window

 public:

   //////////
   // Construct a Message object with a given text string and an
   // associated position where it will be displayed in a Frame's
   // visible window.
     // <UL>
     // <LI><B>textString</B>: the text string to be displayed.</LI>
     // <LI><B>whereAt</B>: the Location of where the text string will
     //be drawn. </LI>
     // </UL>
   Message(char *textString, Location whereAt);

   //////////
   // Construct a Message object with a default text string (the empty string)
   // and an
   // associated position where it will be displayed in a Frame's
   // visible window.
   // <UL>
   // <LI><B>whereAt</B>: the Location of where the text string will
   //be drawn. </LI>
   // </UL>
   Message(Location whereAt);

   //////////
   // Define in which Frame object the text string will be drawn.
   // <UL>
   // <LI><B>whichFrame</B>: the Frame in whose visible window the
   // text string will be drawn. </LI>
   // </UL>
   void DisplayIn(Frame& whichFrame);
 
   //////////
   // Change the location of where the text string is drawn. If the text
   // is currently visible, it will be erased from its current location
   // and redrawn at its new location.
   // <UL>
   // <LI><B>newLocation</B>: the new Location at which the 
   // text string will be drawn. </LI>
   // </UL>
   void MoveTo(Location newLocation);

   //////////
   // Change the text that is displayed.
   // <UL>
   // <LI><B>newText</B>: the new text string that will be drawn. If the
   // text string is currently visible, it will be erased and redrawn.</LI>
   // </UL>
   void SetText(char *newText);

   //////////
   // Return the current text string of the Message.
   char *GetText();

   //////////
   // Draw the current text string in the Frame with which the Message is
   // currently associated at the Message's current Location. This
   // method has no effect if the Message is not associated with a
   // Frame.</LI>
   void Draw();

   //////////
   // Erase the current text string from the Frame with which the Message
   // is currently associated.
   void Clear();

   //////////
   // Release the resources associated with the Message object.
   ~Message();
};

#endif



