#ifndef _TEXTFRAME_H_
#define _TEXTFRAME_H_

#include "BscFrame.h"
#include "wx.h"
#include "Shape.h"
#include "Location.h"

/*
CLASS
     TextFrame

   This class captures the abstraction of a window into which
   information can be written in a stream-like fashion. 
   The window is constructed in a way
   similar to a Frame (with a name, Location, and Shape) and may also
   be moved and resized. Unlike a Frame, the TextFrame provides a
   set of stream I/O operators that allow basic types to be converted
   into text and displayed in the window. Formatting is primitive:
   blanks between fields are inserted by streaming to the window a
   text string of blanks, lines are ended by streamng to the window
   the newline ('\n') or end-of-line (EOL) character.
*/
class TextFrame {
 private:
   Location          location;
   Shape             shape;
   char             *name;
   BasicTextFrame   *frame;

   void CreateIfNeeded();

public:

   //////////
   // Construct a TextFrame with the given name, Location, and Shape.
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //                 will appear on the top border of the window on the user's
  //                 display.</LI>
  //<LI><B>location</B> the coordinates of where the Frame's upper left-hand
  //                    corner is located on the user's display relative to 
  //                    the upper left-hand corner of the display.
  //<LI><B>shape</B> the height and width of the Frame, measured in pixels.
  //</UL>
   TextFrame(char *name, Location location, Shape shape);

  //////////
  // Construct a TextFrame with the given name and Location. A default
  // Shape is used for the TextFrame's window.
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //                 will appear on the top border of the window on the user's
  //                 display.</LI>
  //<LI><B>location</B> the coordinates of where the Frame's upper left-hand
  //                    corner is located on the user's display relative to 
  //                    the upper left-hand corner of the display.
  //</UL>
   TextFrame(char* name, Location loc);

  //////////
  // Construct a TextFrame with the given name and Shape. A default 
  // Location is used for the placement of the window on the user's 
  // display.
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //                 will appear on the top border of the window on the user's
  //                 display.</LI>
  //<LI><B>shape</B> the height and width of the Frame, measured in pixels.
  //</UL>
   TextFrame(char* name, Shape sh);

   //////////
   // Construct a TextFrame with the given name. Default values are used
  // for the placement and size of the window on the user's display.
  //<UL>
  //<LI><B>name</B>: this string defines the name of the Frame. This string 
  //                 will appear on the top border of the window on the user's
  //                 display.</LI>
  //</UL>
   TextFrame(char* name);

  //////////
  // Construct a TextFrame with default values used for the name, 
  // Location, and Shape.
  //<UL>
   TextFrame();


   //////////
   // Reclaim all resources associated with the TextFrame when the TextFrame
   // object is deleted.
  ~TextFrame();
            

   //////////
   // Move the TextFrame's visible window to a specified Location.
   //<UL>
   //<LI><B>location</B>: the new position of the upper left-hand
   //corner of the Frame's visible window.
   //</UL>
   void     MoveTo( Location location);              


   //////////
   // Change the dimensions of the TextFrame's visible window to a 
   // specified Shape.
   //<UL>
   // <LI><B>shape</B>: the new dimensons for the window.
   //</UL>
   void     Resize( Shape shape);                  

   //////////
   // Change the dimensions of the TextFrame's visible window by multiplying
   // each dimension by a given amount.
   //<UL>
   // <LI><B>factor</B>: the amount by which the window's height and
   //width are multiplied. If factor &gt; 1, the window will increase in
   //size. If factor &lt; 1, the window will decrease in size.
   //</UL>
   void     Resize( float factor);              

   //////////
   // Reply if the given string is equal to the name of the Frame.
   //<UL>
   // <LI><B>name</B>: Return 1 if this string matches the name given
   // to the Frame when the Frame was constructed. Return 0 otherwise.</LI>
   //</UL>
   int      IsNamed(char* n);                   

   //////////
   // An overloaded stream output operator that outputs a character
   // string to the TextFrame. The text characters of the string
   // are placed at the end of the current utput stream displayed in
   // the TextFrame's visible window.
   //<UL>
   // <LI><B>stringValue</B>: the text string to be output to the
   // TextFrame.</LI>
   //</UL>
   TextFrame& operator<<(char  *stringValue);

   //////////
   // An overloaded stream output operator that outputs an integer
   // value to the TextFrame. The integer value is converted to a 
   // string of text characters that  are placed at the end of the 
   // current utput stream displayed in the TextFrame's visible window.
   //<UL>
   // <LI><B>intValue</B>: the integer value to be output to the
   // TextFrame.</LI>
   //</UL>
   TextFrame& operator<<(int    intValue);

   //////////
   // An overloaded stream output operator that outputs a long integer
   // value to the TextFrame. The long integer value is converted to a 
   // string of text characters that  are placed at the end of the 
   // current output stream displayed in the TextFrame's visible window.
   //<UL>
   // <LI><B>longValue</B>: the long integer value to be output to the
   // TextFrame.</LI>
   //</UL>
   TextFrame& operator<<(long   longValue);

   //////////
   // An overloaded stream output operator that outputs a floating point
   // value to the TextFrame. The long integer value is converted to a 
   // string of text characters that  are placed at the end of the 
   // current output stream displayed in the TextFrame's visible window.
   //<UL>
   // <LI><B>longValue</B>: the floating point value to be output to the
   // TextFrame.</LI>
   //</UL>
   TextFrame& operator<<(float  floatValue);

   //////////
   // An overloaded stream output operator that outputs a double-length
   // floating point value to the TextFrame. The double-length
   // floating point value is converted to a 
   // string of text characters that  are placed at the end of the 
   // current output stream displayed in the TextFrame's visible window.
   //<UL>
   // <LI><B>doubleValue</B>: the double-length floating point value 
   // to be output to the TextFrame.</LI>
   //</UL>
   TextFrame& operator<<(double doubleValue);

   //////////
   // An overloaded stream output operator that outputs a single character
   // value to the TextFrame. The character value is placed at the end of the 
   // current output stream displayed in the TextFrame's visible window.
   //<UL>
   // <LI><B>charValue</B>: the character value to be output to the
   // TextFrame.</LI>
   //</UL>
   TextFrame& operator<<(char   charValue);

};


#endif


