#ifndef _QUERY_H
#define _QUERY_H

/*
CLASS
   Query

   This class represents the abstraction of a "text search query". A
   Query maintains two text strings, one representing a string of
   text to be searched for (the "search" string) and one representing 
   the outcome of the search (the "result" string). The Query does not
   engage in the search but simply provides a container for the
   input to a search and the results. Get and set methods are provided
   for each of the two strings (the search string and the result string).
   In addition, the user may be asked to supply the search string through
   a modal dialogue.

*/

class Query {
 private:
  char* search;
  char* result;
 public:

  //////////
  // Construct a Query object with a given search string.
  //<UL>
  //<LI><B> searchText</B>: the text string that will be searched for.</LI>
  //</UL>
  Query (char* searchText);

  //////////
  // Construct a Query object with an undefined search string. Presumably,
  // the <I>SetSearch</I> method will be used later to define the
  // search string.
  Query();

  //////////
  // Set the search string to a given text string. This method allows
  // the search string, if any, given at the time of construction to be
  // changed. The previous search string is deleted. This method also 
  // allows the same Query object to be used for different searches.
  //<UL>
  //<LI><B>searchText</B>: the next search string of the Query object. </LI>
  //</UL>
  void   SetSearch(char* searchText);

  //////////
  // Return a copy of the current search string of the Query object. 
  // This method does not change the search string.
  char*  GetSearch();

  //////////
  // Initiate a modal dialogue in which the user enters a text string
  // that is assigned as the current search string. The method does not
  // return until the user has finished with the dialogue.
  void AskUser();

  //////////
  // Set the result string to a given text string. This method would
  // be called by an object performing a search (see the File class).
  // Any previous result string is deleted.
  //<UL>
  //<LI><B> resultText</B>: the new value for the result text.</LI>
  //</UL>
  void   SetResult(char* resultText);

  //////////
  // Return a copy of the current result string. This method does not
  // change the Query object's result string.
  char*  GetResult();

  //////////
  // Reclaim the resources (the search and result strings) when the Query
  // object is deleted.
  ~Query();
};

#endif
