#ifndef _MESSAGE_H
#define _MESSAGE_H

#include "Location.h"
#include "Canvas.h"

/*
CLASS
  Message

  This class captures the abstraction of a text string that can be
  drawn and erased from a given Location in a Frame with which the
  Message is associated.

*/

class Message {
 private:
   char     *text;               // text being displayed
   Location  location;           // at this location
   Canvas    *canvas;              // in this window

 public:

   //////////
   // Construct a Message object with a given text string and an
   // associated position where it will be displayed in a Canvas's
   // visible region.
     // <UL>
     // <LI><B>textString</B>: the text string to be displayed.</LI>
     // <LI><B>whereAt</B>: the Location of where the text string will
     //be drawn. </LI>
     // </UL>
   Message(char *textString, Location whereAt);

   //////////
   // Construct a Message object with a default text string (the empty string)
   // and an
   // associated position where it will be displayed in a Canvas's
   // visible region.
   // <UL>
   // <LI><B>whereAt</B>: the Location of where the text string will
   //be drawn. </LI>
   // </UL>
   Message(Location whereAt);

   //////////
   // Construct a new Message object whose initialization is based on
   // an existing Message object. Only the text string is initialized.
   // The existing Message object is passed by reference and the parameter
   // is declared <I><B>const</B></I> because the existing object is not
   // changed as a result of constructing the new Message object.
   // <UL>
   // <LI><B>other </B>: The existing Message object. </LI>
   // </UL>
   Message (const Message& other);  // copy constructor

   //////////
   // Define in which Canvas object the text string will be drawn.
   // <UL>
   // <LI><B>whichCanvas</B>: the Canvas in whose visible region the
   // text string will be drawn. </LI>
   // </UL>
   void DisplayIn(Canvas& whichCanvas);

   //////////
   // Change the location of where the text string is drawn. If the text
   // is currently visible, it will be erased from its current location
   // and redrawn at its new location.
   // <UL>
   // <LI><B>newLocation</B>: the new Location at which the 
   // text string will be drawn. </LI>
   // </UL>
   void MoveTo(Location newLocation);

   //////////
   // Change the text that is displayed.
   // <UL>
   // <LI><B>newText</B>: the new text string that will be drawn. If the
   // text string is currently visible, it will be erased and redrawn.</LI>
   // </UL>
   void SetText(char *newText);

   //////////
   // Return the current text string of the Message.
   char *GetText();

   //////////
   // Draw the current text string in the Canvas with which the Message is
   // currently associated at the Message's current Location. This
   // method has no effect if the Message is not associated with a
   // Canvas.</LI>
   void Draw();

   //////////
   // Erase the current text string from the Canvas with which the Message
   // is currently associated.
   void Clear();

   //////////
   // Define a class-specific assignment operator. This method defines
   // what occurs when one Message object is assigned to another
   // Message object using the standard assignment operator (=).
   // <UL>
   //<LI><B>other  </B>: the Message object on the right hand of the
   // assignment operator. In this definition, only the text string in
   // the Message object is assigned to the current object (i.e., the
   // values of the current object's Location and Canvas attributes are
   // unchanged by the assignment. The <I>other</I> Message object is
   // passed by reference and declared as <I><B>const</B></I> because
   // the right-hand Message object is not changed by the assignment.</LI>
   //</UL>
   void operator= (const Message& other); //assignment operator

   //////////
   // Release the resources associated with the Message object.
   ~Message();
};

#endif



