
#ifndef _POLYSHAPE_H
#define _POLYSHAPE_H

#include "LocationNode.h"
#include "Canvas.h"

/*
CLASS
  PolyShape

  This class captures the abstraction of a closed polygon shape. The
  class constructor defines the first node (vertex) of the shape. The PolyShape
  maintains a "current" point that can be changed by relative, navigational
  methods - <I>Up</I>, <I>Down</I>, <I>Left</I>, and <I>Right</I> - 
  which move the "current" point in the indicated direction. When the
  <I>Mark</I> method is invoked, the "current" point is added as the
  next nodes (vertex) in the shape. The <I>Draw</I> method draws in a
  specified Canvas the closed  polygon corresponding to the set of nodes 
  (vertices). The  polygon is closed in that the last node (vertex) is assumed 
  to be connected to the first node (vertex).
*/

class PolyShape
{
private:
	LocationNode *head;
	LocationNode *tail;
	int currentX, currentY;
	int length;
public:

        //////////
        // Initialize the first node (vertex) and "current" point of 
        // the PolyShape with the specified x and y coordinates.
        //<UL>
	//<LI><B>x </B>: the x coordinate of the first point and the
        // initial current point. </LI>
	//<LI><B>y </B>: the y coordinate of the first point and the
        // initial current point. </LI>
        //</UL>
	PolyShape(int x, int y); 

        //////////
        // Move the "current" point toward the top edge of the display area
        // by the specified amount. Distances are measured in pixels.
        //<UL>
	//<LI><B>amount</B>: the amount to move the "current" point.
        //</UL>
	void Up   (int amount);

        //////////
        // Move the "current" point toward the botton edge of the display area
        // by the specified amount. Distances are measured in pixels.
        //<UL>
	//<LI><B>amount</B>: the amount to move the "current" point.
        //</UL>
	void Down (int amount);

        //////////
        // Move the "current" point toward the left edge of the display area
        // by the specified amount. Distances are measured in pixels.
        //<UL>
	//<LI><B>amount</B>: the amount to move the "current" point.
        //</UL>
	void Left (int amount);

        //////////
        // Move the "current" point toward the right edge of the display area
        // by the specified amount. Distances are measured in pixels.
        //<UL>
	//<LI><B>amount</B>: the amount to move the "current" point.
        //</UL>
	void Right(int amount);

        //////////
        // Add the "current" point as the next node (vertex) of closed polygon.
	void Mark();

        //////////
        // Draw the closed polygon described by the nodes of the PolyShape.
        // The PolyShape is drawn by drawing line segments connecting
        // successive pairs of nodes (vertices) defined in the PolyShape.
        // The PolyShape drawing is closed by drawing a line from the
        // last node (vertex) to the first node (vertex). The drawing
        // is done in the specified Canvas.
        //<UL>
        //<LI><B>canvas </B>: the Canvas in which the PolyShape will be
        // drawn </LI>
        //</UL>
	void Draw(Canvas& canvas);

        //////////
        // Reclaim the resources associated with the PolyShape when the
        // PolyShape object is destructed. The resources include the
        // list of nodex (vertices) and their supporting data structure
        // components.
	~PolyShape();
};

#endif
