#ifndef _STOPWATCH_H
#define _STOPWATCH_H

#include "Button.h"
#include "Location.h"
#include "Shape.h"
#include "Clock.h"
#include "Canvas.h"
#include "Panel.h"
#include "Counter.h"
#include "Message.h"

/*
CLASS
  StopWatch

  This class captures the abstraction of a simple timing device that
  can be started and stopped. A simple elaspsed time value is maintained
  and drawn by the StopWatch. Two Buttons, named "Start" and "Stop"
  allow the timing to be halted or resumed. Stopping the StopWatch
  does NOT reset the internal elapsed time counter.
  
*/
class StopWatch
{
  private:
	  Button  startButton;
	  Button  stopButton; 
	  Clock   clock;
	  Counter clockCount;
	  Message clockDisplay;
	  Panel   buttonPanel;
	  Canvas  canvas;

  public:

          //////////
          //
          //<UL>
          //<LI><B>frame </B>: the Frame object in which the StopWatch
          // will be displayed. </LI>
          //<LI><B>where </B>: the Location within the Frame object of
          // the upper left-hand corner reference position for
          // the StopWatch. </LI>
          //<LI><B>interval </B>: the interval of time between increments
          // of the StopWatch (defaults to 1,000 msec == 1 second).</LI>
          //</UL>
	  StopWatch(Frame& frame, Location where, 
		        int interval = 1000);

          //////////
          //  Determine which of the two StopWatch's Buttons was pushed
          // by the user. The name must match either the name of the
          // Start button or the name of the Stop button.
          //<UL>
          //<LI><B>buttonName </B>: the text string name of the button
          // that was pushed.  </LI>
          //</UL>
	  void ButtonPushed(char* buttonName);

          //////////
          // Increment the current value (the elapsed time) of the 
          // StopWatchby 1. This method is iDInvoked (indirectly) by 
          // the encapsulated Clock within the the StopWatch object. 
          // The Clock invokes the OnTimerEvent  method which must be 
          // programmed to invoke this method.
	  void Tick();

          //////////
          // Report the current value of the timer. Note: since the
          // StopWatch may be stop and (re)started, the current value
          // need not correspond to the true elapsed time since the
          // StopWatch was first started.
	  int ElapsedTime();

          //////////
          // Delete the internal components of the StopWatch when the
          // StopWatch itself is deleted.
	  ~StopWatch();

};
#endif
